# Examples

This folder contains a few examples of how the package can be used.  
Keep in mind since this is a package for handling and raising errors that most of them are meant to error out in the end.
